@@ -12,6 +12,7 @@ from borgmatic.hooks import (
     ntfy,
     pagerduty,
     postgresql,
+    pushover,
     sqlite,
     uptimekuma,
     zabbix,
@@ -31,6 +32,7 @@ HOOK_NAME_TO_MODULE = {
     'ntfy': ntfy,
     'pagerduty': pagerduty,
     'postgresql_databases': postgresql,
+    'pushover': pushover,
     'sqlite_databases': sqlite,
     'uptime_kuma': uptimekuma,
     'zabbix': zabbix,
