@@ -9,15 +9,11 @@ from borgmatic.hooks import dump
 logger = logging.getLogger(__name__)
 
 
-def make_dump_path(config, base_directory=None):  # pragma: no cover
+def make_dump_path(base_directory):  # pragma: no cover
     '''
-    Given a configuration dict and an optional base directory, make the corresponding dump path. If
-    a base directory isn't provided, use the borgmatic runtime directory.
+    Given a base directory, make the corresponding dump path.
     '''
-    return dump.make_data_source_dump_path(
-        base_directory or borgmatic.config.paths.get_borgmatic_runtime_directory(config),
-        'sqlite_databases',
-    )
+    return dump.make_data_source_dump_path(base_directory, 'sqlite_databases')
 
 
 def use_streaming(databases, config, log_prefix):
@@ -28,11 +24,11 @@ def use_streaming(databases, config, log_prefix):
     return any(databases)
 
 
-def dump_data_sources(databases, config, log_prefix, dry_run):
+def dump_data_sources(databases, config, log_prefix, borgmatic_runtime_directory, dry_run):
     '''
     Dump the given SQLite databases to a named pipe. The databases are supplied as a sequence of
-    configuration dicts, as per the configuration schema. Use the given configuration dict to
-    construct the destination path and the given log prefix in any log entries.
+    configuration dicts, as per the configuration schema. Use the given borgmatic runtime directory
+    to construct the destination path and the given log prefix in any log entries.
 
     Return a sequence of subprocess.Popen instances for the dump processes ready to spew to a named
     pipe. But if this is a dry run, then don't actually dump anything and return an empty sequence.
@@ -52,7 +48,7 @@ def dump_data_sources(databases, config, log_prefix, dry_run):
                 f'{log_prefix}: No SQLite database at {database_path}; an empty database will be created and dumped'
             )
 
-        dump_path = make_dump_path(config)
+        dump_path = make_dump_path(borgmatic_runtime_directory)
         dump_filename = dump.make_data_source_dump_filename(dump_path, database['name'])
 
         if os.path.exists(dump_filename):
@@ -80,43 +76,55 @@ def dump_data_sources(databases, config, log_prefix, dry_run):
     return processes
 
 
-def remove_data_source_dumps(databases, config, log_prefix, dry_run):  # pragma: no cover
+def remove_data_source_dumps(
+    databases, config, log_prefix, borgmatic_runtime_directory, dry_run
+):  # pragma: no cover
     '''
-    Remove the given SQLite database dumps from the filesystem. The databases are supplied as a
-    sequence of configuration dicts, as per the configuration schema. Use the given configuration
-    dict to construct the destination path and the given log prefix in any log entries. If this is a
-    dry run, then don't actually remove anything.
+    Remove all database dump files for this hook regardless of the given databases. Use the
+    borgmatic runtime directory to construct the destination path and the log prefix in any log
+    entries. If this is a dry run, then don't actually remove anything.
     '''
-    dump.remove_data_source_dumps(make_dump_path(config), 'SQLite', log_prefix, dry_run)
+    dump.remove_data_source_dumps(
+        make_dump_path(borgmatic_runtime_directory), 'SQLite', log_prefix, dry_run
+    )
 
 
-def make_data_source_dump_patterns(databases, config, log_prefix, name=None):  # pragma: no cover
+def make_data_source_dump_patterns(
+    databases, config, log_prefix, borgmatic_runtime_directory, name=None
+):  # pragma: no cover
     '''
-    Make a pattern that matches the given SQLite databases. The databases are supplied as a sequence
-    of configuration dicts, as per the configuration schema.
+    Given a sequence of configurations dicts, a configuration dict, a prefix to log with, the
+    borgmatic runtime directory, and a database name to match, return the corresponding glob
+    patterns to match the database dump in an archive.
     '''
     borgmatic_source_directory = borgmatic.config.paths.get_borgmatic_source_directory(config)
 
     return (
+        dump.make_data_source_dump_filename(make_dump_path('borgmatic'), name, hostname='*'),
         dump.make_data_source_dump_filename(
-            make_dump_path(config, 'borgmatic'), name, hostname='*'
+            make_dump_path(borgmatic_runtime_directory), name, hostname='*'
         ),
-        dump.make_data_source_dump_filename(make_dump_path(config), name, hostname='*'),
         dump.make_data_source_dump_filename(
-            make_dump_path(config, borgmatic_source_directory), name, hostname='*'
+            make_dump_path(borgmatic_source_directory), name, hostname='*'
         ),
     )
 
 
 def restore_data_source_dump(
-    hook_config, config, log_prefix, data_source, dry_run, extract_process, connection_params
+    hook_config,
+    config,
+    log_prefix,
+    data_source,
+    dry_run,
+    extract_process,
+    connection_params,
+    borgmatic_runtime_directory,
 ):
     '''
     Restore a database from the given extract stream. The database is supplied as a data source
-    configuration dict, but the given hook configuration is ignored. The given configuration dict is
-    used to construct the destination path, and the given log prefix is used for any log entries. If
-    this is a dry run, then don't actually restore anything. Trigger the given active extract
-    process (an instance of subprocess.Popen) to produce output to consume.
+    configuration dict, but the given hook configuration is ignored. The given log prefix is used
+    for any log entries. If this is a dry run, then don't actually restore anything. Trigger the
+    given active extract process (an instance of subprocess.Popen) to produce output to consume.
     '''
     dry_run_label = ' (dry run; not actually restoring anything)' if dry_run else ''
     database_path = connection_params['restore_path'] or data_source.get(
